# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/dreamai_dl',
                'doc_host': 'https://HamzaFarhan.github.io',
                'git_url': 'https://github.com/HamzaFarhan/dreamai_dl',
                'lib_path': 'dreamai_dl'},
  'syms': { 'dreamai_dl.core': {},
            'dreamai_dl.imports': {},
            'dreamai_dl.utils': { 'dreamai_dl.utils.default_device': ('utils.html#default_device', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.is_tensor': ('utils.html#is_tensor', 'dreamai_dl/utils.py'),
                                  'dreamai_dl.utils.plt_show': ('utils.html#plt_show', 'dreamai_dl/utils.py')}}}
